pub(crate) struct Placeholder {
pub(crate) ident: Var,
stand_in_name: String,
pub(crate) constraints: Vec<Constraint>,
}Fields
ident: VarThe name of this placeholder. e.g. for “$a”, this would be “a”
stand_in_name: StringA unique name used in place of this placeholder when we parse the pattern as Rust code.
constraints: Vec<Constraint>Implementations
Sourceimpl Placeholder
impl Placeholder
fn new(name: SmolStr, constraints: Vec<Constraint>) -> Self